@@ -32,14 +32,9 @@ def get_config(folder, variant=None):
         config_files = find_config_files(folder)
     console.print(f"\nLoading config files: [green]{', '.join(config_files)}\n")
     parsed_cfg = collections.OrderedDict()
+
     for f in config_files:
         parsed_cfg[f] = parse_config_file(f, config)
-        normalized = {}
-        for k in parsed_cfg[f].keys():
-            if "_" in k:
-                n = k.replace("_", "-")
-                normalized[n] = parsed_cfg[f][k]
-        parsed_cfg[f].update(normalized)
 
     # TODO just using latest config here, should merge!
     if len(config_files):
